@@ -25,6 +25,7 @@ class DatabaseConnector(AbstractDatabaseConnector, AsyncInitable, AsyncDeinitabl
         pool_recycle: int = -1  # Maximum number of seconds a connection can persist. It defaults to -1 (no timeout).
         pool_timeout: int = 30  # Maximum number of seconds to wait when retrieving a new connection from the pool
         echo: bool = False  # log all executed sql commands
+        pool_pre_ping: bool = True
 
     def __init__(self, config: Config):
         AsyncInitable.__init__(self)
@@ -45,7 +46,8 @@ class DatabaseConnector(AbstractDatabaseConnector, AsyncInitable, AsyncDeinitabl
 
         self.engine = create_async_engine(
             address, echo=self._config.echo, pool_size=self._config.pool_size, max_overflow=self._config.max_overflow,
-            pool_recycle=self._config.pool_recycle, pool_timeout=self._config.pool_timeout)
+            pool_recycle=self._config.pool_recycle, pool_timeout=self._config.pool_timeout,
+            pool_pre_ping=self._config.pool_pre_ping)
 
     async def _async_init(self):
         if self._config.auto_table_creation_enabled:
